![rendering](./doc/rendering.webp)

### Start

1. Install and upgrade  
  `pip install -U windows_font_manager`

2. Open WebUI  
  (Click the URL from terminal)

### Develop

* Backend  
  Python 3.14 (>=3.12)  
  `debugpy` from VSCode

* WebUI  
  `pnpm --dir .\windows-font-manager-webui\ dev`

* Build or install  
  `py run_build.py` or `pip install .`
